Package 'sfneighbourconnector'

Title: Interactively add neighbour connections to sf objects
Description: This add-in allows you to select an sf object in your environment and manually add connections to the neighbour list created by spdep's "poly2nb" function.
Authors: Erik-Jan van Kesteren [aut, cre]
Maintainer: Erik-Jan van Kesteren <[email protected]>
License: MIT
Version: 0.1.0
Built: 2026-05-27 08:17:57 UTC
Source: https://github.com/vankesteren/sfneighbourconnector

Help Index


Launch Manual Neighbor Connector Add-in

Description

Starts a Shiny gadget for manually connecting polygon neighbors in the Viewer pane.

Usage

runNeighborConnector()